@@ -11,14 +11,14 @@ use warnings;
 
 package WaitReSS::App::Action::import;
 {
-  $WaitReSS::App::Action::import::VERSION = '0.002';
+  $WaitReSS::App::Action::import::VERSION = '0.003';
 }
 # ABSTRACT: Implementation of import command
 
 use XML::OPML::LibXML;
 
-use WaitReSS::App -command;
-use WaitReSS::Feeds;
+use WaitReSS::Config;
+use WaitReSS::Users;
 
 
 # -- public methods
@@ -27,14 +27,28 @@ use WaitReSS::Feeds;
 sub run {
     my ($pkg, $opts, $args) = @_;
 
+    # check which user is registering
+    my $login = $opts->{user} // $config->get( "cli.default.user" );
+    if ( ! defined $login ) {
+        error( "Must specify a user for this command." );
+        exit 1;
+    }
+    my $user = $users->by_login( $login );
+    if ( ! defined $user ) {
+        error( "User $login doesn't exist");
+        exit 1;
+    }
+
+    # parse opml file
     my $file = shift @$args;
     my $opml = XML::OPML::LibXML->new;
     my $doc  = $opml->parse_file($file);
 
+    # register feeds for the user
     $doc->walkdown( sub {
         my $outline = shift;
         return if $outline->is_container;
-        $feeds->register( $outline->xml_url );
+        $user->register(  $outline->xml_url );
     } );
 }
 
@@ -51,7 +65,7 @@ WaitReSS::App::Action::import - Implementation of import command
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 DESCRIPTION
 
